class Admin::LinksController < ApplicationController

  layout "content"
  
  before_filter :authenticate_user!
  before_filter :find_parent_item
  before_filter :is_admin?
  
  def show
    @link ||= Link.find(params[:id])
  end
  
  def new
    @link = Link.new
    @link.is_published = true
    @link.parent_id = Page.find(params[:parent_id]).id rescue nil
  end

  def edit
    @link = Link.find(params[:id])
    @i18n_variable = @link.i18n_variable
  end

  def create
    @link = Link.new(params[:link])

    if @link.save
      flash.now[:notice] = t('admin.create_success_link')
      respond_to do |format|
        format.html { 
          redirect_to admin_link_url(@link) 
        }
        format.js  {}
      end
    else
      flash.now[:error] = t('admin.create_error_link')
      @i18n_variable = @link.i18n_variable
      render :action => "new"
    end
  end

  def update
    @link = Link.find(params[:id])

    if @link.update_attributes(params[:link])
      flash.now[:notice] = t('admin.update_success_link')
      respond_to do |format|
        format.html { 
          redirect_to admin_link_url(@link) 
        }
        format.js  {}
      end
    else
      flash.now[:error] = t('admin.update_error_link')
      @i18n_variable = @link.i18n_variable
      render :action => "edit"
    end
  end

  def destroy
    @link = Link.find(params[:id])
    @link.destroy
    @link.destroy_i18n_variable
  end
  
  def delete
    destroy
    respond_to do |format|
      format.html { 
        redirect_to admin_items_url
      }
      format.js  {}
    end
  end
  
end
